@@ -5,8 +5,7 @@
 #' vectors, lists, matrices or data.frames) or to arbitrarily aggregate them, which is a more general
 #' operation.
 #'
-#' @param reg [\code{\link{Registry}}]\cr
-#'   Registry.
+#' @template arg_reg
 #' @param ids [\code{integer}]\cr
 #'   Ids of selected jobs.
 #'   Default is all jobs for which results are available.
@@ -45,7 +44,7 @@
 #'   Default is \code{TRUE}.
 #' @param strings.as.factors [\code{logical(1)}]
 #'   Should all character columns in result be converted to factors?
-#'   Default is \code{default.stringsAsFactors()}.
+#'   Default is \code{FALSE}.
 #' @return Aggregated results, return type depends on function. If \code{ids} is empty: \code{reduceResults}
 #'   returns \code{init} (if available) or \code{NULL}, \code{reduceResultsVector} returns \code{c()},
 #'   \code{reduceResultsList} returns \code{list()}, \code{reduceResultsMatrix} returns \code{matrix(0,0,0)},
@@ -84,7 +83,7 @@
 #' # reduce results to a sum
 #' reduceResults(reg, fun = function(aggr, job, res) aggr+res$a, init = 0)
 reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val, progressbar = TRUE, ...) {
-  checkRegistry(reg)
+  checkRegistry(reg, writeable = FALSE)
   syncRegistry(reg)
   if (missing(ids)) {
     ids = done = dbFindDone(reg)
@@ -121,12 +120,12 @@ reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val,
       aggr = init
     }
 
-    for (id in ids) {
+    not.done = (ids %nin% done)
+    for (i in seq_along(ids)) {
       # use lazy evaluation
       aggr = fun(aggr,
-                 job = dbGetJobs(reg, id)[[1L]],
-                 res = if (with.impute && id %nin% done)
-                   impute.val else getResult(reg, id, part),
+                 job = dbGetJobs(reg, ids[i])[[1L]],
+                 res = if (with.impute && not.done[i]) impute.val else getResult(reg, ids[i], part),
                  ...)
       bar$inc(1L)
     }
@@ -138,7 +137,7 @@ reduceResults = function(reg, ids, part = NA_character_, fun, init, impute.val,
 #' @rdname reduceResults
 reduceResultsList = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids",
   impute.val, progressbar = TRUE) {
-  checkRegistry(reg)
+  checkRegistry(reg, writeable = FALSE)
   syncRegistry(reg)
   if (missing(ids)) {
     ids = done = dbFindDone(reg)
@@ -219,7 +218,7 @@ reduceResultsMatrix = function(reg, ids, part = NA_character_, fun, ..., rows =
 #' @export
 #' @rdname reduceResults
 reduceResultsDataFrame = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids", impute.val,
-  strings.as.factors = default.stringsAsFactors()) {
+  strings.as.factors = FALSE) {
   assertFlag(strings.as.factors)
 
   res = reduceResultsList(reg, ids, part, fun, ..., use.names = use.names, impute.val = impute.val)
@@ -228,3 +227,12 @@ reduceResultsDataFrame = function(reg, ids, part = NA_character_, fun, ..., use.
 
   convertListOfRowsToDataFrame(res, strings.as.factors = strings.as.factors)
 }
+
+#' @export
+#' @rdname reduceResults
+reduceResultsDataTable = function(reg, ids, part = NA_character_, fun, ..., use.names = "ids", impute.val) {
+  res = reduceResultsList(reg, ids, part, fun, ..., use.names = use.names, impute.val = impute.val)
+  if (!length(res))
+    return(data.table())
+  rbindlist(res, fill = TRUE)
+}
