@@ -9,7 +9,7 @@ test_that("batchMap", {
   expect_equal(y, (1:3)^2, check.attributes = FALSE)
 
   reg = makeTestRegistry()
-  batchMap(reg, function(x,y,z) (x+y)*z, 1:3, 4:6, more.args=list(z=2))
+  batchMap(reg, function(x,y,z) (x+y)*z, 1:3, 4:6, more.args = list(z = 2))
   submitJobs(reg)
   waitForJobs(reg)
   y = sapply(getJobIds(reg), function(id) loadResult(reg, id))
@@ -19,26 +19,21 @@ test_that("batchMap", {
   expect_equal(batchMap(reg, function(...) 1), integer(0L))
   expect_equal(batchMap(reg, function(...) 1, i = integer(0L)), integer(0L))
 
-
   reg = makeTestRegistry()
   expect_equal(batchMap(reg, function(...) 1, a = 1:3, b = 1:3, use.names = TRUE), 1:3)
+
+  # factors
+  reg = makeTestRegistry()
+  ids = batchMap(reg, identity, factor(letters[1:5]))
+  submitJobs(reg)
+  waitForJobs(reg)
+  expect_equal(loadResults(reg, simplify = TRUE), setNames(factor(letters[1:5]), 1:5))
+
+  # primitive functions
+  reg = makeTestRegistry()
+  ids = batchMap(reg, sin, 1:2)
+  submitJobs(reg)
+  waitForJobs(reg)
+  expect_equal(as.numeric(loadResults(reg, simplify = TRUE)), sin(1:2))
 })
 
-
-#FIXME reenable that test if we have a better working example
-# test_that("batchMap non atomic", {
-#   # factors
-#   reg = makeTestRegistry()
-#   ids = batchMap(reg, identity, factor(letters[1:5]))
-#   submitJobs(reg)
-#   waitForJobs(reg)
-#   expect_equal(loadResults(reg, simplify=TRUE), setNames(factor(letters[1:5]), 1:5))
-#
-#   reg = makeTestRegistry()
-#   ids = batchMap(reg, identity, overloaded.index.obj)
-#   submitJobs(reg)
-#   res = loadResults(reg, use.names=FALSE, simplify=TRUE)
-#   expect_equal(res, 3:1)
-# })
-
-
